@@ -35,6 +35,7 @@ void definePointTypes(py::module &m)
 
     py::class_<pcl::PointXYZ, pcl::shared_ptr<pcl::PointXYZ>> (m_pts, "PointXYZ")
             .def(py::init<>())
+            .def(py::init<float, float, float>())
             .def_readwrite("x", &pcl::PointXYZ::x)
             .def_readwrite("y", &pcl::PointXYZ::y)
             .def_readwrite("z", &pcl::PointXYZ::z);
@@ -52,6 +53,7 @@ void definePointTypes(py::module &m)
 
     py::class_<pcl::PointXYZRGB, pcl::shared_ptr<pcl::PointXYZRGB>> (m_pts, "PointXYZRGB")
             .def(py::init<>())
+//            .def(py::init<float, float, float, uint8_t, uint8_t, uint8_t>())
             .def_readwrite("x", &pcl::PointXYZRGB::x)
             .def_readwrite("y", &pcl::PointXYZRGB::y)
             .def_readwrite("z", &pcl::PointXYZRGB::z)
